@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
 import logging
 
 logger = logging.getLogger('giza.main')
@@ -26,13 +25,16 @@ import giza.operations.configuration
 import giza.operations.deploy
 import giza.operations.generate
 import giza.operations.git
+import giza.operations.http_serve
 import giza.operations.includes
 import giza.operations.make
 import giza.operations.packaging
+import giza.operations.build_env
 import giza.operations.quickstart
-import giza.operations.sphinx
+import giza.operations.sphinx_cmds
 import giza.operations.translate
 import giza.operations.tx
+import giza.operations.code_review
 
 commands = {
     'main': [
@@ -40,16 +42,25 @@ commands = {
         giza.operations.configuration.render_config,
         giza.operations.deploy.main,
         giza.operations.deploy.publish_and_deploy,
-        giza.operations.make.main,
         giza.operations.quickstart.make_project,
-        giza.operations.sphinx.main,
-        giza.operations.deploy.twofa_code
+        giza.operations.sphinx_cmds.main,
+        giza.operations.deploy.twofa_code,
+        giza.operations.http_serve.start,
+        giza.operations.configuration.report_version,
+        giza.operations.make.main
     ],
     'git': [
         giza.operations.git.apply_patch,
         giza.operations.git.pull_rebase,
         giza.operations.git.cherry_pick,
         giza.operations.git.merge,
+        giza.operations.git.create_branch,
+    ],
+    'cr': [
+        giza.operations.code_review.create_or_update,
+        giza.operations.code_review.list_reviews,
+        giza.operations.code_review.close,
+        giza.operations.code_review.checkout,
     ],
     'generate': [
         giza.operations.generate.api,
@@ -63,7 +74,9 @@ commands = {
         giza.operations.generate.toc,
         giza.operations.generate.examples,
         giza.operations.generate.redirects,
-        giza.operations.generate.robots
+        giza.operations.generate.robots,
+        giza.operations.generate.source,
+        giza.operations.generate.release,
     ],
     'includes': [
         giza.operations.includes.recursive,
@@ -80,6 +93,10 @@ commands = {
         giza.operations.packaging.create,
         giza.operations.packaging.deploy,
     ],
+    'env': [
+        giza.operations.build_env.package,
+        giza.operations.build_env.extract,
+    ],
     'translate': [
         giza.operations.translate.create_corpora,
         giza.operations.translate.build_translation_model,
@@ -101,6 +118,11 @@ commands = {
 }
 
 def get_base_parser():
+    """
+    Adds global arguments/settings giza build process, and creates the top-level
+    argument parser object.
+    """
+
     parser = argh.ArghParser()
     parser.add_argument('--level', '-l',
                         choices=['debug', 'warning', 'info', 'critical', 'error'],
@@ -110,10 +132,26 @@ def get_base_parser():
     parser.add_argument('--event', default=None, dest='runner', const='event', action='store_const')
     parser.add_argument('--process', default=None, dest='runner', const='process', action='store_const')
     parser.add_argument('--force', '-f', default=False, action='store_true')
+    parser.add_argument('--fast', action='store_true')
 
     return parser
 
 def main():
+    """
+    The main entry point, as specified in the ``setup.py`` file. Adds commands
+    from other subsidiary entry points (specified in the ``commands`` variable
+    above,) and then uses ``arch.dispatch()`` to start the process.
+
+    The ``RuntimeStateConfig()`` object is created here and handed to the parser
+    as the object that will recive all command line data, rather than using a
+    standard argparse namespace object. This allows all runtime argument parsing
+    to happen inside of these config objects rather than spread among all of the
+    entry points.
+
+    This function catches and recovers from :exc:`KeyboardInterupt` which means
+    that doesn't dump a stack trace following a Control-C.
+    """
+
     parser = get_base_parser()
 
     for namespace, entry_points in commands.items():
