@@ -19,7 +19,7 @@ logger = logging.getLogger('giza.config.helper')
 from giza.config.base import ConfigurationBase
 
 class PdfConfig(ConfigurationBase):
-    _option_registry = ['source', 'title', 'tag', 'author', 'class']
+    _option_registry = ['source', 'title', 'tag', 'author', 'class', 'edition']
 
     @property
     def output(self):
