@@ -16,7 +16,7 @@ import logging
 import os.path
 import yaml
 
-from multiprocessing import cpu_count
+import multiprocessing
 
 logger = logging.getLogger('giza.config.runtime')
 
@@ -51,7 +51,13 @@ class RuntimeStateConfigurationBase(ConfigurationBase):
 
     @function.setter
     def function(self, value):
-        self.state['_entry_point'] = value
+        if callable(value):
+            self.state['_entry_point'] = value
+        else:
+            raise TypeError
+
+    def get_function(self):
+        return self.state['_entry_point']
 
     @property
     def force(self):
@@ -108,6 +114,20 @@ class RuntimeStateConfigurationBase(ConfigurationBase):
 
         logger.debug('set logging level to: ' + value)
 
+    @property
+    def fast(self):
+        if 'fast_and_loose' not in self.state:
+            return False
+        else:
+            return self.state['fast_and_loose']
+
+    @fast.setter
+    def fast(self, value):
+        if isinstance(value, bool):
+            self.state['fast_and_loose'] = value
+        else:
+            logger.warning('invalid option for "fast" build option')
+
     @property
     def runner(self):
         if 'runner' not in self.state:
@@ -120,7 +140,7 @@ class RuntimeStateConfigurationBase(ConfigurationBase):
         supported_runners = ['process', 'thread', 'event', 'serial']
 
         if value is None:
-            self.state['runner'] = 'thread'
+            self.state['runner'] = 'process'
         elif value in supported_runners:
             self.state['runner'] = value
         else:
@@ -131,9 +151,12 @@ class RuntimeStateConfigurationBase(ConfigurationBase):
     @property
     def pool_size(self):
         if 'pool_size' not in self.state:
-            return cpu_count()
-        else:
-            return self.state['pool_size']
+            try:
+                self.state['pool_size'] = multiprocessing.cpu_count()
+            except:
+                self.state['pool_size'] = 1
+
+        return self.state['pool_size']
 
     @pool_size.setter
     def pool_size(self, value):
@@ -186,8 +209,8 @@ class RuntimeStateConfigurationBase(ConfigurationBase):
 
 class RuntimeStateConfig(RuntimeStateConfigurationBase):
     _option_registry = [ 'serial', 'length', 'days_to_save',
-                         'builder_to_delete', 'git_branch', 'make_target',
-                         'git_sign_patch', 'serial_sphinx', 'package_path',
+                         'git_branch', 'make_target',
+                         'git_sign_patch', 'package_path',
                          'clean_generated', 'include_mask', 'push_targets',
                          'dry_run', 't_corpora_config', 't_translate_config',
                          't_output_file', 't_source', 't_target', 'port']
@@ -196,6 +219,20 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
         super(RuntimeStateConfig, self).__init__(obj)
         self._branch_conf = None
 
+    @property
+    def serial_sphinx(self):
+        if 'serial_sphinx' in self.state:
+            return self.state['serial_sphinx']
+        else:
+            return None
+
+    @serial_sphinx.setter
+    def serial_sphinx(self, value):
+        if value is False:
+            pass
+        else:
+            self.state['serial_sphinx'] = value
+
     @property
     def conf_path(self):
         if 'conf_path' not in self.state:
@@ -260,6 +297,7 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
         if 'builder' not in self.state:
             return [ ]
         elif 'publish' in self.state['builder']:
+            self.fast = False
             self.state['builder'].remove('publish')
 
             if 'integration' in self.conf.system.files.data:
@@ -315,7 +353,9 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
 
     @editions_to_build.setter
     def editions_to_build(self, value):
-        if isinstance(value, list):
+        if value == [] or value is None:
+            self.state['editions_to_build'] = [None]
+        elif isinstance(value, list):
             self.state['editions_to_build'] = value
         else:
             self.state['editions_to_build'] = [value]
@@ -326,7 +366,9 @@ class RuntimeStateConfig(RuntimeStateConfigurationBase):
 
     @languages_to_build.setter
     def languages_to_build(self, value):
-        if isinstance(value, list):
+        if value == [] or value is None:
+            self.state['languages_to_build'] = [None]
+        elif isinstance(value, list):
             self.state['languages_to_build'] = value
         else:
             self.state['languages_to_build'] = [value]
