@@ -12,6 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Post-process all output produced by JSON to add a "text" field to these
+documents that omits the XML data injected into this format by default so that
+search tools can use this data to index content. Also generates a file with a
+list of paths in the output.
+"""
+
 import json
 import re
 import os
@@ -21,7 +28,7 @@ logger = logging.getLogger('giza.content.post.json_output')
 
 from giza.tools.command import command
 from giza.tools.strings import dot_concat
-from giza.tools.files import expand_tree, copy_if_needed
+from giza.tools.files import expand_tree, copy_if_needed, safe_create_directory
 from giza.tools.transformation import munge_content
 
 ########## Process Sphinx Json Output ##########
@@ -35,10 +42,7 @@ def json_output(conf):
     cmd = 'rsync --recursive --times --delete --exclude="*pickle" --exclude=".buildinfo" --exclude="*fjson" {src} {dst}'
 
     json_dst = os.path.join(conf.paths.projectroot, conf.paths.public_site_output, 'json')
-
-    if not os.path.exists(json_dst):
-        logger.debug('created directories for {0}'.format(json_dst))
-        os.makedirs(json_dst)
+    safe_create_directory(json_dst)
 
     builder = 'json'
     if 'edition' in conf.project and conf.project.edition != conf.project.name:
@@ -126,9 +130,8 @@ def process_json_file(input_fn, output_fn, regexes, conf=None):
 
         doc['title'] = title
 
-    url = [ conf.project.url, conf.project.basepath ]
+    url = get_site_url(conf)
     url.extend(input_fn.rsplit('.', 1)[0].split(os.path.sep)[3:])
-
     doc['url'] = '/'.join(url) + '/'
 
     with open(output_fn, 'w') as f:
@@ -138,16 +141,28 @@ def process_json_file(input_fn, output_fn, regexes, conf=None):
 
 def generate_list_file(outputs, path, conf):
     dirname = os.path.dirname(path)
+    safe_create_directory(dirname)
 
-    url = '/'.join([ conf.project.url, conf.project.basepath, 'json' ])
-
-    if not os.path.exists(dirname):
-        os.mkdir(dirname)
+    url = get_site_url(conf)
+    url.append('json')
+    url = '/'.join(url)
 
     with open(path, 'w') as f:
         for fn in outputs:
             if os.path.isfile(fn) is True:
-                f.write( '/'.join([ url, fn.split('/', 3)[3:][0]]) )
+                line = '/'.join([ url, fn.split('/', 3)[3:][0]])
+                f.write(line)
                 f.write('\n')
 
     logger.info('rebuilt inventory of json output.')
+
+def get_site_url(conf):
+    url = [conf.project.url]
+
+    if conf.project.basepath not in ('', None):
+        url.append(conf.project.basepath)
+
+    if conf.project.branched is True and 'editions' in conf.project:
+        url.append(conf.git.branches.current)
+
+    return url
