@@ -24,28 +24,9 @@ from giza.tools.command import command
 from giza.tools.serialization import ingest_yaml_list, ingest_yaml_doc
 from giza.tools.transformation import munge_page
 from giza.tools.files import (expand_tree, create_link, copy_if_needed,
-                              decode_lines_from_file, encode_lines_to_file)
-
-def manual_single_html(input_file, output_file):
-    # don't rebuild this if its not needed.
-    if check_dependency(output_file, input_file) is False:
-        logging.info('singlehtml not changed, not reprocessing.')
-        return False
-    else:
-        text_lines = decode_lines_from_file(input_file)
-
-        regexes = [
-            (re.compile('href="contents.html'), 'href="index.html'),
-            (re.compile('name="robots" content="index"'), 'name="robots" content="noindex"'),
-            (re.compile('href="genindex.html'), 'href="../genindex/')
-        ]
-
-        for regex, subst in regexes:
-            text_lines = [ regex.sub(subst, text) for text in text_lines ]
-
-        encode_lines_to_file(output_file, text_lines)
-
-        logging.info('processed singlehtml file.')
+                              decode_lines_from_file, encode_lines_to_file,
+                              safe_create_directory)
+from giza.content.post.singlehtml import get_single_html_dir
 
 #################### Sphinx Post-Processing ####################
 
@@ -66,41 +47,6 @@ def finalize_epub_build(builder, conf):
                                         epub_src_filename))
 
 
-def get_single_html_dir(conf):
-    return os.path.join(conf.paths.public_site_output, 'single')
-
-def finalize_single_html_jobs(builder, conf):
-    pjoin = os.path.join
-
-    single_html_dir = get_single_html_dir(conf)
-
-    if not os.path.exists(single_html_dir):
-        os.makedirs(single_html_dir)
-
-    try:
-        manual_single_html(input_file=pjoin(conf.paths.branch_output,
-                                                    builder, 'contents.html'),
-                                   output_file=pjoin(single_html_dir, 'index.html'))
-    except (IOError, OSError):
-        manual_single_html(input_file=pjoin(conf.paths.branch_output,
-                                                    builder, 'index.html'),
-                                   output_file=pjoin(single_html_dir, 'index.html'))
-    copy_if_needed(source_file=pjoin(conf.paths.branch_output,
-                                     builder, 'objects.inv'),
-                   target_file=pjoin(single_html_dir, 'objects.inv'))
-
-    single_path = pjoin(single_html_dir, '_static')
-
-    for fn in expand_tree(pjoin(conf.paths.branch_output,
-                                builder, '_static'), None):
-
-        yield {
-            'job': copy_if_needed,
-            'args': [fn, pjoin(single_path, os.path.basename(fn))],
-            'target': None,
-            'dependency': None
-        }
-
 def error_pages(sconf, conf):
     builder = sconf.builder
 
@@ -115,27 +61,26 @@ def error_pages(sconf, conf):
                                 'meta', error, 'index.html')
             munge_page(fn=page, regex=sub, tag='error-pages')
 
-        logging.info('error-pages: rendered {0} error pages'.format(idx))
+        logger.info('error-pages: rendered {0} error pages'.format(idx))
 
 def finalize_dirhtml_build(sconf, conf):
-    pjoin = os.path.join
     builder = sconf.builder
 
     single_html_dir = get_single_html_dir(conf)
-    search_page = pjoin(conf.paths.branch_output, builder, 'index.html')
+    search_page = os.path.join(conf.paths.branch_output, builder, 'index.html')
 
     if os.path.exists(search_page):
         copy_if_needed(source_file=search_page,
-                       target_file=pjoin(single_html_dir, 'search.html'))
+                       target_file=os.path.join(single_html_dir, 'search.html'))
 
-    dest = pjoin(conf.paths.projectroot, conf.paths.public_site_output)
-    m_cmd = command('rsync -a {source}/ {destination}'.format(source=sconf.build_output,
+    dest = os.path.join(conf.paths.projectroot, conf.paths.public_site_output)
+    m_cmd = command('rsync -a {source}/ {destination}'.format(source=sconf.fq_build_output,
                                                               destination=dest))
 
-    logger.info('"{0}" migrated build from {1} to {2}, with result {3}'.format(sconf.name, sconf.build_output, dest, m_cmd.return_code))
+    logger.info('"{0}" migrated build from {1} to {2}, with result {3}'.format(sconf.name, sconf.fq_build_output, dest, m_cmd.return_code))
 
     if 'excluded_files' in sconf:
-        fns = [ pjoin(conf.paths.projectroot,
+        fns = [ os.path.join(conf.paths.projectroot,
                       conf.paths.public_site_output,
                       fn)
                 for fn in sconf['dirhtml']['excluded_files'] ]
@@ -146,13 +91,15 @@ def finalize_dirhtml_build(sconf, conf):
     if conf.git.branches.current in conf.git.branches.published:
         sitemap_exists = sitemap(config_path=None, conf=conf)
 
-        if sitemap_exists is True:
-            copy_if_needed(source_file=pjoin(conf.paths.projectroot,
-                                             conf.paths.branch_output,
-                                             'sitemap.xml.gz'),
-                           target_file=pjoin(conf.paths.projectroot,
-                                             conf.paths.public_site_output,
-                                             'sitemap.xml.gz'))
+        legacy_sitemap_fn = os.path.join(conf.paths.projectroot,
+                                         conf.paths.branch_output,
+                                         'sitemap.xml.gz')
+
+        if os.path.exists(legacy_sitemap_fn) and sitemap_exists is True:
+            copy_if_needed(source_file=legacy_sitemap_fn,
+                           target_file=os.path.join(conf.paths.projectroot,
+                                                    conf.paths.public_site_output,
+                                                    'sitemap.xml.gz'))
 
 
 def sitemap(config_path, conf):
