@@ -12,6 +12,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Content migration and transformation engine that makes it possible to import and
+reuse content from repository, or project in another. Migration specifications
+can also include transformation specifications to trim content from a source
+file, append content to a file, or apply a regular expression substitution.
+
+Developed for the Primer/Getting Started section. Configuration files are all
+``.yaml`` files in the *config* directory that have the substring "migration" in
+them. Uses the functions in :mod:`giza.tools.transformation` and
+:mod:`giza.tools.files` to perform the action, and just adds migration and
+transformation tasks to a :class:`giza.core.app.BuildApp()` instance.
+"""
+
 import os
 import logging
 
@@ -89,6 +102,8 @@ def trim_leading_slash_from_pages(page):
 def resolve_page_path(page, conf):
     if page['target'].startswith('/'):
         fq_target = page['target']
+    elif '{root}' in page['target']:
+        fq_target = page['target'].format(root=conf.paths.projectroot)
     else:
         fq_target = os.path.join(conf.paths.projectroot, conf.paths.source, page['target'])
 
@@ -130,7 +145,7 @@ def primer_migration_tasks(conf, app):
             prev = build_migration_task(fq_target, fq_source, app)
 
             if 'truncate' in page:
-                build_truncate_task(page['truncate'], fq_target, app)
+                build_truncate_task(page['truncate'], fq_target, fq_source, app)
 
             if 'transform' in page:
                 prev.job = copy_always
@@ -147,6 +162,9 @@ def primer_migration_tasks(conf, app):
 
         return True
 
+
+########## Task Creators
+
 def clean(conf, app):
     "Removes all migrated primer files according to the current spec."
 
@@ -170,12 +188,12 @@ def clean(conf, app):
 
     logger.info('clean: removed {0} files'.format(len(targets)))
 
-########## Task Creators
-
 def build_migration_task(target, source, app):
     task = app.add('task')
     task.target = target
     task.job = copy_if_needed
+    task.target = target
+    task.dependency = source
     task.args = [ source, target, 'primer' ]
 
     return task
@@ -190,13 +208,14 @@ def build_transform_task(transform, target):
 def build_append_task(page, target, spec_files, app):
     task = app.add('task')
     task.target = page['target']
+    task.dependency = spec_files
     task.job = append_to_file
     task.args = [ target, page['append'] ]
-    task.dependency = spec_files
 
-def build_truncate_task(truncate_spec, target, app):
+def build_truncate_task(truncate_spec, target, deps, app):
     task = app.add('task')
     task.target = target
+    task.dependency = deps
     task.job = truncate_file
     task.args = {
         'fn': target,
