@@ -20,15 +20,23 @@ from other content units and optionally override some portions of the inherited
 units.
 """
 
+import copy
+import collections
 import logging
 import os.path
-
+import sys
+import copy
 logger = logging.getLogger('giza.core.inheritance')
 
+from jinja2 import Template
+
 from giza.config.base import RecursiveConfigurationBase, ConfigurationBase
 from giza.tools.serialization import ingest_yaml_list
 from giza.content.helper import level_characters, edition_check
 
+if sys.version_info >= (3, 0):
+    basestring = str
+
 class InheritableContentError(Exception):
     """
     Exception used by inheritance code to indicate a problem resolving
@@ -45,6 +53,45 @@ class InheritableContentBase(RecursiveConfigurationBase):
 
     _option_registry = ['pre', 'post', 'final', 'ref', 'content', 'edition']
 
+    def _get_default_replacement(self):
+        if 'replacement' in self.conf.system.files.data:
+            base = copy.deepcopy(self.conf.system.files.data.replacement)
+        else:
+            base = {}
+
+        return base
+
+    @property
+    def replacement(self):
+        if 'replacement' not in self.state:
+            self.state['replacement'] = self._get_default_replacement()
+
+        return self.state['replacement']
+
+    @replacement.setter
+    def replacement(self, value):
+        if 'replacement' in self.state:
+            if value in ({}, None):
+                return
+            base = self.state['replacement']
+        else:
+            base = self._get_default_replacement()
+
+        if isinstance(value, dict):
+            base.update(value)
+            self.state['replacement'] = base
+        elif isinstance(value, collections.Iterable):
+            for item in value:
+                if len(item) != 2:
+                    raise TypeError
+
+            addition = dict(value)
+            base.update(addition)
+            self.state['replacement'] = base
+        else:
+            raise TypeError
+
+
     @property
     def title(self):
         return self.state['title']
@@ -88,24 +135,75 @@ class InheritableContentBase(RecursiveConfigurationBase):
             logger.warning(str(data) + ' is not resolvable')
             return False
 
+    def has_field(self, name):
+        if name in self and getattr(self, name, None) is not None:
+            return True
+        else:
+            return False
+
     def resolve(self, data):
         if self._is_resolveable(data):
             try:
                 base = data.fetch(self.source.file, self.source.ref)
                 base.resolve(data)
 
+                needs_replacement = self.replacement != base.replacement
+
+                if needs_replacement:
+                    replacement = copy.deepcopy(base.replacement)
+                    replacement.update(self.replacement)
+
                 base.state.update(self.state)
                 self.state.update(base.state)
+
+                if needs_replacement:
+                    self.replacement = replacement
+
                 self.source.resolved = True
                 return True
             except InheritableContentError as e:
                 logger.error(e)
 
-        if self.source is not None and not self.source.is_resolved():
+        if not self.is_resolved():
             m = 'cannot find {0} and ref "{1}" do not exist'.format(self.source.file, self.source.ref)
             logger.error(m)
             raise InheritableContentError(m)
 
+    def render(self):
+        if self.replacement:
+            attempts = range(10)
+
+            for key in self.state.keys():
+                if isinstance(self.state[key], collections.Iterable):
+                    should_resplit = None
+
+                    if isinstance(self.state[key], list):
+                        for it in self.state[key]:
+                            if not isinstance(it, basestring):
+                                should_resplit = False
+                        if should_resplit is None:
+                            should_resplit = True
+                            self.state[key] = '\n'.join(self.state[key])
+
+                    for i in attempts:
+                        if '{{' not in self.state[key]:
+                            break
+
+                        template = Template(self.state[key])
+                        self.state[key] = template.render(**self.replacement)
+
+                        if '{{' not in self.state[key]:
+                            break
+
+                    if should_resplit is True:
+                        self.state[key] = self.state[key].split('\n')
+                elif isinstance(self.state[key], InheritableContentBase):
+                    if len(self.state[key].replacement) == 0:
+                        self.state[key].replacement = self.replacement
+
+                    self.state[key].render()
+
+
 class InheritanceReference(RecursiveConfigurationBase):
     """
     Represents a single reference to another unit of content. The
@@ -138,17 +236,20 @@ class InheritanceReference(RecursiveConfigurationBase):
 
     @file.setter
     def file(self, value):
-        if 'file' in self.state and os.path.exists(self.state['file']):
-            return
+        # if 'file' in self.state and os.path.isfile(self.state['file']):
+        #     return
 
         fns = set([ # value,  os.path.abspath(value),
                    os.path.join(self.conf.paths.projectroot, value),
                    os.path.join(self.conf.paths.projectroot,
-                                self.conf.paths.includes, value) ])
+                                self.conf.paths.branch_includes, value),
+                   # os.path.join(self.conf.paths.projectroot,
+                   #              self.conf.paths.includes, value)
+                                ])
 
         try:
             fns.add(os.path.join(self.conf.paths.projectroot,
-                                    self.conf.paths.source, value))
+                                 self.conf.paths.source, value))
         except KeyError:
             pass
 
@@ -212,19 +313,24 @@ class DataContentBase(RecursiveConfigurationBase):
                 continue
             try:
                 self.add(doc)
-            except:
-                print(doc)
+            except Exception as e:
+                logger.error('could not inherit, because: ' + str(e))
+                logger.info(doc)
 
     def add(self, doc):
-        if 'ref' not in doc:
-            if 'source' in doc:
-                ref = doc['source']['ref']
-            elif 'inherit' in doc:
-                ref = doc['inherit']['ref']
+        if 'ref' in doc:
+            ref = doc['ref']
+        elif 'source' in doc:
+            ref = doc['source']['ref']
+        elif 'inherit' in doc:
+            ref = doc['inherit']['ref']
+        else:
+            ref = None
 
+        if 'ref' not in doc and ref is not None:
             doc['ref'] = ref
 
-        if doc['ref'] not in self.content:
+        if ref not in self.content:
             if isinstance(doc, self.content_class):
                 content = doc
             else:
@@ -233,6 +339,9 @@ class DataContentBase(RecursiveConfigurationBase):
                 except TypeError:
                     content = self.content_class(doc, self.conf)
 
+            if ref is not None:
+                content.ref = ref
+
             self.content[content.ref] = content
 
             if not content.is_resolved():
@@ -252,7 +361,7 @@ class DataContentBase(RecursiveConfigurationBase):
             if not content.is_resolved():
                 content.resolve(self)
 
-            return content
+            return copy.deepcopy(content)
         else:
             m = 'content with ref "{0}" not found'.format(ref)
             logger.error(m)
@@ -268,6 +377,8 @@ class DataContentBase(RecursiveConfigurationBase):
             return True
 
     def resolve(self):
+        """Resolves all inheritance."""
+
         for exmp in self.content.values():
             exmp.resolve(self.data)
 
@@ -284,6 +395,9 @@ class DataCache(RecursiveConfigurationBase):
         self._conf = conf
         self.ingest(files)
 
+    def __len__(self):
+        return len(self._cache)
+
     @property
     def cache(self):
         return self._cache
@@ -318,13 +432,29 @@ class DataCache(RecursiveConfigurationBase):
     def fetch(self, fn, ref):
         if fn not in self.cache:
             logger.error('file "{0}" is not included.'.format(fn))
-            raise InheritableContentError
+            if os.path.isfile(fn):
+                self.add_file(fn)
+            else:
+                raise InheritableContentError
 
         if self.cache[fn] == []:
             self.add_file(fn)
 
         return self.cache[fn].fetch(ref)
 
+    def file_iter(self):
+        for fn in self.cache:
+            yield fn, self.cache[fn]
+
+    def content_iter(self):
+        for fn in self.cache:
+            for data in self.cache[fn].content.values():
+                if data.ref.startswith('_'):
+                    continue
+                else:
+                    yield fn, data
+
+
 class TitleData(ConfigurationBase):
     _option_registry = ['text']
 
