@@ -34,7 +34,12 @@ class PoolResultsError(Exception): pass
 def run_task(task):
     "helper to call run method on task so entire operation can be pickled for process pool support"
 
-    return task.run()
+    try:
+        result = task.run()
+    except KeyboardInterrupt:
+        logger.error('task received interrupt.')
+
+    return result
 
 class WorkerPool(object):
     def __enter__(self):
@@ -82,7 +87,11 @@ class WorkerPool(object):
                 if ret is None:
                     retval.append(ret)
                 else:
-                    retval.append(ret.get())
+                    try:
+                        retval.append(ret.get())
+                    except KeyboardInterrupt:
+                        logger.critical("received keyboard interrupt. exiting")
+                        return
             except Exception as e:
                 has_errors = True
                 errors.append((job, e))
@@ -92,7 +101,7 @@ class WorkerPool(object):
             for job, err in errors:
                 error_list.append(e)
                 if job.description is None:
-                    logger.error("encountered error '{0}' in {1} with args ({2})".format(e, job.job, job.args))
+                    logger.error("encountered error '{0}' in {1}".format(e, job.job))
                 else:
                     logger.error("'{0}' encountered error: {1}, exiting.".format(job.description, e))
 
@@ -112,7 +121,15 @@ class SerialPool(object):
     def runner(self, jobs):
         results = []
         for job in jobs:
-            logger.info('running: ' + job.description)
+            if job.needs_rebuild is False:
+                continue
+
+            if job.description is not None:
+                msg = job.description
+            else:
+                msg = str(job.job)
+
+            logger.info('running: ' + msg)
             results.append(job.run())
 
         return results
@@ -123,13 +140,13 @@ class ThreadPool(WorkerPool):
     def __init__(self, conf=None):
         self.conf = new_skeleton_config(conf)
         self.p = multiprocessing.dummy.Pool(self.conf.runstate.pool_size)
-        logger.info('new thread pool object')
+        logger.debug('new thread pool object')
 
 class ProcessPool(WorkerPool):
     def __init__(self, conf=None):
         self.conf = new_skeleton_config(conf)
         self.p = multiprocessing.Pool(self.conf.runstate.pool_size)
-        logger.info('new process pool object')
+        logger.debug('new process pool object')
 
 class EventPool(WorkerPool):
     def __init__(self, conf=None):
@@ -141,4 +158,4 @@ class EventPool(WorkerPool):
             raise PoolConfigurationError('gevent is not available')
 
         self.p = gevent.pool.Pool(self.conf.runstate.pool_size)
-        logger.info('new event pool object')
+        logger.debug('new event pool object')
