@@ -117,7 +117,8 @@ def mine_github_pulls(gh, app, conf):
 
 #################### mdbpr commands #####################
 
-@argh.arg('--path', dest='user_conf_path', default='.github.yaml')
+@argh.arg('--path', dest='conf_path', default='.github.yaml')
+@argh.expects_obj
 def setup(args):
     skel = {
         'site': { 'credentials': "~/.giza-credentials.yaml",
@@ -130,18 +131,18 @@ def setup(args):
 
     dump_skel(skel, args)
 
+@argh.expects_obj
 def mine(args):
     conf = fetch_config(args)
     app = BuildApp(conf)
-    app.pool = 'thread'
     gh = get_connection(conf)
 
     pprint(mine_github_pulls(gh, app, conf))
 
+@argh.expects_obj
 def stats(args):
     conf = fetch_config(args)
     app = BuildApp(conf)
-    app.pool = 'thread'
     gh = get_connection(conf)
 
     users = set()
@@ -158,10 +159,10 @@ def stats(args):
 
     pprint(result)
 
+@argh.expects_obj
 def actions(args):
     conf = fetch_config(args)
     app = BuildApp(conf)
-    app.pool = 'thread'
     gh = get_connection(conf)
 
     results = []
