@@ -12,6 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+Create and manipulate "packages" of build artifacts that can be used to quickly
+share and deploy artifacts and build environment data.
+"""
+
 import logging
 import datetime
 import os
@@ -28,11 +33,14 @@ import argh
 
 from giza.config.helper import fetch_config
 from giza.tools.serialization import dict_from_list
-from giza.operations.deploy import deploy_worker
+from giza.tools.files import safe_create_directory, FileNotFoundError
+from giza.operations.deploy import deploy_tasks
 
 ############### Helper ###############
 
-def package_filename(archive_path, target, conf):
+def package_filename(target, conf):
+    archive_path = os.path.join(conf.paths.projectroot, conf.paths.buildarchive)
+
     fn = [ conf.project.name ]
 
     if target is not None:
@@ -48,8 +56,6 @@ def package_filename(archive_path, target, conf):
 
     return fn
 
-#################### Worker Functions ####################
-
 def dump_config(conf):
     # make sure the object is fully resolved before we put it into storage
     dynamics = [conf.deploy]
@@ -65,52 +71,55 @@ def dump_config(conf):
 
     return conf_dump_path
 
+def create_archive(files_to_archive, tarball_name):
+    # ready to write the tarball
+
+    safe_create_directory(os.path.dirname(tarball_name))
+
+    with tarfile.open(tarball_name, 'w:gz') as t:
+        for fn, arc_fn in files_to_archive:
+            t.add(name=fn, arcname=arc_fn)
+
+#################### Worker Functions ####################
+
 def create_package(target, conf):
+    logger.info('creating package for target "{0}"'.format(target))
+
     if target is None:
         pconf = conf.system.files.data.push[0]
         target = pconf['target']
     else:
-        pconf = dict_from_list(conf.system.files.data.push)[target]
+        pconf = dict_from_list('target', conf.system.files.data.push)[target]
 
-    logger.info('creating package for target "{0}"'.format(target))
-
-    conf_dump_path = dump_config(conf)
-
-    arc_path = os.path.join(conf.paths.projectroot, conf.paths.buildarchive)
-    arc_fn = package_filename(arc_path, target, conf)
-    if not os.path.exists(arc_path):
-        os.makedirs(arc_path)
-
-    input_path = os.path.join(conf.paths.projectroot,
-                              conf.paths.output,
-                              pconf['paths']['local'])
-    output_path_name = conf.git.branches.current
+    files_to_archive = []
 
     if conf.project.branched is True:
-        input_path = os.path.join(input_path, conf.git.branches.current)
+        artifacts = (os.path.join(conf.paths.output, conf.git.branches.current), conf.git.branches.current)
     else:
-        output_path_name = os.path.split(pconf['paths']['local'])[-1]
+        artifacts = (os.path.join(conf.paths.projectroot, conf.paths.output, pconf['paths']['local']),
+                     os.path.split(pconf['paths']['local'])[-1])
 
-    # ready to write the tarball
-    with tarfile.open(arc_fn, 'w:gz') as t:
-        t.add(name=input_path,
-              arcname=output_path_name)
-        t.add(conf_dump_path, arcname=os.path.basename(conf_dump_path))
+    files_to_archive.append(artifacts)
 
-        if 'static' in pconf['paths']:
-            for path in pconf['paths']['static']:
-                rendered_path = os.path.join(conf.paths.projectroot,
-                                             conf.paths.public, path)
-                if os.path.exists(rendered_path):
-                    t.add(name=rendered_path,
-                          arcname=path)
+    if 'static' in pconf['paths']:
+        files_to_archive.extend([
+            (os.path.join(conf.paths.projectroot, conf.paths.public, path), path)
+            for path in pconf['paths']['static']
+            if os.path.exists(os.path.join(conf.paths.projectroot, conf.paths.public, path))
+        ])
 
-    logger.info('wrote build package to: {0}'.format(arc_fn))
+    conf_dump_path = dump_config(conf)
+    archive_fn = package_filename(target, conf)
+    files_to_archive.append((conf_dump_path, os.path.basename(conf_dump_path)))
+
+    create_archive(files_to_archive, archive_fn)
+
+    logger.info('wrote build package to: {0}'.format(archive_fn))
 
 def extract_package(conf):
     if conf.runstate.package_path.startswith('http'):
         path = fetch_package(path, conf)
-    elif os.path.exists(conf.runstate.package_path):
+    elif os.path.isfile(conf.runstate.package_path):
         path = conf.runstate.package_path
     else:
         m = "package {0} does not exist".format(conf.runstate.package_path)
@@ -131,28 +140,34 @@ def extract_package(conf):
     return new_conf
 
 def fetch_package(path, conf):
-    if not path.startswith('http') and os.path.exists(path):
+    if path.startswith('http'):
+
+        local_path = path.split('/')[-1]
+
+        tar_path = os.path.join(conf.paths.projectroot,
+                                conf.paths.buildarchive,
+                                local_path)
+
+        if not os.path.exists(tar_path):
+            with closing(urllib2.urlopen(path)) as u:
+                with open(tar_path, 'w') as f:
+                    f.write(u.read())
+            logger.info('downloaded {0}'.format(local_path))
+        else:
+            logger.info('{0} exists locally, not downloading.'.format(local_path))
+
+        return tar_path
+    elif os.path.isfile(path):
         return path
-
-    local_path = path.split('/')[-1]
-
-    tar_path = os.path.join(conf.paths.projectroot,
-                            conf.paths.buildarchive,
-                            local_path)
-
-    if not os.path.exists(tar_path):
-        with closing(urllib2.urlopen(path)) as u:
-            with open(tar_path, 'w') as f:
-                f.write(u.read())
-        logger.info('downloaded {0}'.format(local_path))
     else:
-        logger.info('{0} exists locally, not downloading.'.format(local_path))
-
-    return tar_path
+        msg = 'no archive named "{0}" exists'.format(path)
+        logger.error(msg)
+        raise FileNotFoundError(msg)
 
 #################### Command Entry Points ####################
 
-@argh.arg('--target', '-t', nargs=1, default=[None], dest='push_targets')
+@argh.arg('--target', '-t', nargs=1, dest='push_targets')
+@argh.expects_obj
 def create(args):
     conf = fetch_config(args)
     target = conf.runstate.push_targets[0]
@@ -160,6 +175,7 @@ def create(args):
     create_package(target, conf)
 
 @argh.arg('--path', dest='package_path')
+@argh.expects_obj
 def unwind(args):
     conf = fetch_config(args)
 
@@ -171,6 +187,7 @@ def unwind(args):
 @argh.arg('--path', dest='package_path')
 @argh.arg('--target', '-t', nargs=1, dest='push_targets')
 @argh.arg('--dry-run', '-d', action='store_true', dest='dry_run')
+@argh.expects_obj
 def deploy(args):
     conf = fetch_config(args)
 
@@ -183,9 +200,13 @@ def deploy(args):
     app = BuildApp(new_conf)
 
     logger.info('beginning deploy now.')
-    deploy_worker(conf, app)
+    deploy_tasks(conf, app)
+
+    if conf.runstate.dry_run is False:
+        app.run()
 
 @argh.arg('--path', dest='package_path')
+@argh.expects_obj
 def fetch(args):
     conf = fetch_config(args)
 
