@@ -94,7 +94,6 @@ def command(command, capture=True, ignore=False, logger=None):
     if isinstance(command, (list, tuple)):
         command = ' '.join(command)
 
-
     if logger is None:
         log_output = False
         logger = logging.getLogger('giza.command')
@@ -112,11 +111,7 @@ def command(command, capture=True, ignore=False, logger=None):
 
     with open(tmp_out.name, 'w') as tout:
         with open(tmp_err.name, 'w') as terr:
-            p = subprocess.Popen(command, stdout=tout, stderr=terr, shell=True)
-
-            while True:
-                if p.poll() is not None:
-                    break
+            returncode = subprocess.call(command, stdout=tout, stderr=terr, shell=True)
 
     if capture is False:
         stdout = ""
@@ -130,7 +125,7 @@ def command(command, capture=True, ignore=False, logger=None):
     out = CommandResult(cmd=command,
                         err=stderr,
                         out=stdout,
-                        return_code=p.returncode)
+                        return_code=returncode)
     out.captured = capture
 
     if log_output is True and capture is True:
@@ -157,5 +152,7 @@ def verbose_command(cmd, capture=False, ignore=False):
     else:
         cmd_str = cmd
 
+    logger.warning('verbose command is deprecated: ({0})'.format(cmd_str))
+
     logger.info("running command: " + cmd_str)
     command(cmd_str, capture, ignore)
